
# Type: alt_description_source


the source of an attributed description

URI: [meta:alt_description_source](https://w3id.org/biolink/biolinkml/meta/alt_description_source)


## Domain and Range

[AltDescription](AltDescription.md) ->  <sub>REQ</sub> [Ncname](types/Ncname.md)

## Parents


## Children


## Used by

 * [AltDescription](AltDescription.md)
